@@ -42,30 +42,32 @@ AtomMQ::Schema::Result::AtomMQEntry
 
 =head1 VERSION
 
-version 0.0102
+version 0.0200
 
 =head1 ACCESSORS
 
 =head2 id
 
-  data_type: 'integer'
-  is_nullable: 0
-  is_auto_increment: 1
+    data_type: 'integer'
+    is_nullable: 0
+    is_auto_increment: 1
 
 =head2 feed
 
-  data_type: 'text'
-  is_nullable: 1
+    data_type: 'varchar'
+    is_nullable: 1
+    size: 255
 
 =head2 title
 
-  data_type: 'text'
-  is_nullable: 1
+    data_type: 'varchar'
+    is_nullable: 1
+    size: 255
 
 =head2 content
 
-  data_type: 'text'
-  is_nullable: 1
+    data_type: 'text'
+    is_nullable: 1
 
 =head1 AUTHOR
 
